@@ -33,7 +33,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-module.c 6263 2008-05-05 10:52:10Z sfre $
+ * $Id: gedit-module.c 6314 2008-06-05 12:57:53Z pborelli $
  */
 
 #include "config.h"
@@ -226,7 +226,8 @@ void
 gedit_module_class_garbage_collect (GeditModuleClass *klass)
 {
 	g_return_if_fail (GEDIT_IS_MODULE_CLASS (klass));
-	return GEDIT_MODULE_CLASS (klass)->garbage_collect ();
+
+	GEDIT_MODULE_CLASS (klass)->garbage_collect ();
 }
 
 GObject *
