@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h,v 1.39 2006/05/02 10:07:47 sfre Exp $
+ * $Id: gedit-utils.h 6368 2008-08-09 13:37:59Z jessevdk $
  */
 
 #ifndef __GEDIT_UTILS_H__
@@ -68,6 +68,8 @@ void		 gedit_utils_menu_position_under_tree_view
 							 gboolean *push_in,
 							 gpointer  user_data);
 
+gchar		*gedit_gdk_color_to_string		(GdkColor color);
+
 GtkWidget	*gedit_gtk_button_new_with_stock_icon	(const gchar *label,
 							 const gchar *stock_id);
 
@@ -79,9 +81,6 @@ GtkWidget	*gedit_dialog_add_button		(GtkDialog   *dialog,
 gchar		*gedit_utils_escape_underscores		(const gchar *text,
 							 gssize       length);
 
-gchar		*gedit_utils_escape_slashes		(const gchar *text,
-							 gssize       length);
-
 gchar		*gedit_utils_str_middle_truncate	(const gchar *string, 
 							 guint        truncate_length);
 
@@ -106,7 +105,7 @@ gchar		*gedit_utils_unescape_search_text	(const gchar *text);
 
 gchar		*gedit_utils_get_stdin			(void);
 
-void		gedit_warning				(GtkWindow  *parent,
+void		 gedit_warning				(GtkWindow  *parent,
 							 const gchar *format,
 							 ...) G_GNUC_PRINTF(2, 3);
 
@@ -124,25 +123,40 @@ guint		 gedit_utils_get_current_workspace	(GdkScreen *screen);
 
 guint		 gedit_utils_get_window_workspace	(GtkWindow *gtkwindow);
 
+void		 gedit_utils_get_current_viewport	(GdkScreen    *screen,
+							 gint         *x,
+							 gint         *y);
+
 void		 gedit_utils_activate_url		(GtkAboutDialog *about,
 							 const gchar    *url,
 							 gpointer        data);
 
 gboolean	 gedit_utils_is_valid_uri		(const gchar *uri);
 
-gboolean	 gedit_utils_get_glade_widgets		(const gchar  *filename,
-							 const gchar  *root_node,
+gboolean	 gedit_utils_get_ui_objects		(const gchar  *filename,
+                                                         gchar       **root_objects,
 							 GtkWidget   **error_widget,
-							 const gchar  *widget_name,
+							 const gchar  *object_name,
 							 ...) G_GNUC_NULL_TERMINATED;
 
+gboolean         gedit_utils_file_has_parent            (GFile *gfile);
+
 /* Return NULL if str is not a valid URI and/or filename */
 gchar		*gedit_utils_make_canonical_uri_from_shell_arg
 							(const gchar *str);
 		
-/* Like gnome_vfs_format_uri_for_display but removes the password from the 
- * resulting string */
-gchar		*gedit_utils_format_uri_for_display 	(const gchar *uri);
+gchar		*gedit_utils_uri_for_display 	        (const gchar *uri);
+gchar           *gedit_utils_basename_for_display	(const gchar *uri);
+gboolean	 gedit_utils_decode_uri 		(const gchar *uri,
+							 gchar **scheme,
+							 gchar **user,
+							 gchar **port,
+							 gchar **host,
+							 gchar **path);
+
+
+/* Turns data from a drop into a list of well formatted uris */
+gchar 	       **gedit_utils_drop_get_uris		(GtkSelectionData *selection_data);
 
 G_END_DECLS
 
