@@ -28,7 +28,6 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n-lib.h>
-#include <libgnome/gnome-url.h>
 #include <gdk/gdkkeysyms.h>
 #include <gedit/gedit-utils.h>
 #include <gedit/gedit-plugin.h>
@@ -43,7 +42,7 @@
 #include "gedit-file-browser-enum-types.h"
 
 #define GEDIT_FILE_BROWSER_WIDGET_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_FILE_BROWSER_WIDGET, GeditFileBrowserWidgetPrivate))
-#define XML_UI_FILE GEDIT_FILE_BROWSER_DIR "/gedit-file-browser-widget-ui.xml"
+#define XML_UI_FILE GEDIT_UIDIR "/gedit-file-browser-widget-ui.xml"
 #define LOCATION_DATA_KEY "gedit-file-browser-widget-location"
 
 enum 
@@ -625,7 +624,7 @@ insert_location_path (GeditFileBrowserWidget * obj)
 							   obj);
 		}
 
-		if (g_file_equal (current, loc->root) || !_gedit_file_browser_utils_file_has_parent (current)) {
+		if (g_file_equal (current, loc->root) || !gedit_utils_file_has_parent (current)) {
 			if (current != loc->virtual_root)
 				g_object_unref (current);
 			break;
@@ -1072,6 +1071,8 @@ create_tree (GeditFileBrowserWidget * obj)
 	obj->priv->treeview =
 	    GEDIT_FILE_BROWSER_VIEW (gedit_file_browser_view_new ());
 
+	gedit_file_browser_view_set_restore_expand_state (obj->priv->treeview, TRUE);
+
 	gedit_file_browser_store_set_filter_mode (obj->priv->file_store,
 						  GEDIT_FILE_BROWSER_STORE_FILTER_MODE_HIDE_HIDDEN
 						  |
@@ -1085,7 +1086,7 @@ create_tree (GeditFileBrowserWidget * obj)
 					     GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC,
-					GTK_POLICY_ALWAYS);
+					GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (sw),
 			   GTK_WIDGET (obj->priv->treeview));
@@ -1402,29 +1403,36 @@ create_goto_menu_item (GeditFileBrowserWidget * obj, GList * item,
 	GtkWidget *result;
 	GtkWidget *image;
 	gchar *unescape;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf = NULL;
 	Location *loc;
 
 	loc = (Location *) (item->data);
 
 	if (!get_from_bookmark_file (obj, loc->virtual_root, &unescape, &pixbuf)) {
 		unescape = gedit_file_browser_utils_file_basename (loc->virtual_root);
-		pixbuf = g_object_ref (icon);
+		
+		if (icon)
+			pixbuf = g_object_ref (icon);
 	}
 
-	image = gtk_image_new_from_pixbuf (pixbuf);
-	g_object_unref (pixbuf);
+	if (pixbuf) {
+		image = gtk_image_new_from_pixbuf (pixbuf);
+		g_object_unref (pixbuf);
 
-	gtk_widget_show (image);
+		gtk_widget_show (image);
 
-	result = gtk_image_menu_item_new_with_label (unescape);
+		result = gtk_image_menu_item_new_with_label (unescape);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (result),
+					       image);
+	} else {
+		result = gtk_menu_item_new_with_label (unescape);
+	}
+	
 	g_object_set_data (G_OBJECT (result), LOCATION_DATA_KEY, item);
 	g_signal_connect (result, "activate",
 			  G_CALLBACK (on_location_jump_activate), obj);
 
 	gtk_widget_show (result);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (result),
-				       image);
 
 	g_free (unescape);
 
@@ -2530,7 +2538,7 @@ directory_open (GeditFileBrowserWidget *obj,
 	if (FILE_IS_DIR (flags)) {
 		result = TRUE;
 
-		if (!gnome_url_show (uri, &error)) {
+		if (!gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (obj)), uri, GDK_CURRENT_TIME, &error)) {
 			g_signal_emit (obj, signals[ERROR], 0,
 				       GEDIT_FILE_BROWSER_ERROR_OPEN_DIRECTORY,
 				       error->message);
